pub enum Error {
Show 16 variants
ConfigExist(PathBuf),
NoFile(PathBuf, Error),
UnableToParse(Error),
UnableToSerialize(Error),
NoCmdStringFound(PathBuf, String),
CmdStringExists(PathBuf, String),
NoConfigForPath(PathBuf),
Command(Error),
CurrentDir,
ConfigDir,
ConfigPath(Error),
ConfigFileCreation(PathBuf, Error),
ConfigFileWrite(PathBuf, Error),
ConfigDirCreation(PathBuf, Error),
NewConfig(PathBuf),
NoConfigFile,
}Expand description
Error enum with all possible error cases
Variants
ConfigExist(PathBuf)
Configuration alr exists for init cmd
NoFile(PathBuf, Error)
No file found at specified path
UnableToParse(Error)
TOML Parsing error
UnableToSerialize(Error)
TOML Serialization error
NoCmdStringFound(PathBuf, String)
Unable to find the command string in Entry map
CmdStringExists(PathBuf, String)
New command to be inserted already exists
NoConfigForPath(PathBuf)
No configuration file found, even after traversing upwards
Command(Error)
Error running a shell command
CurrentDir
Unable to get CWD
ConfigDir
Unable to get the configuration directory
ConfigPath(Error)
Unable to access configuration path
ConfigFileCreation(PathBuf, Error)
Error while file creation
ConfigFileWrite(PathBuf, Error)
Error while writing to file
ConfigDirCreation(PathBuf, Error)
Error while configuration directory creation
NewConfig(PathBuf)
Created a new configuration, time for the user to update it.
NoConfigFile
When config file is not found